Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(228)

Unified Diff: tools/testing/test_configuration.py

Issue 8496009: Add a leg_only test suite, and make sure to run it in our presubmit script. (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/
Patch Set: '' Created 9 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« frog/tests/leg_only/leg_only.status ('K') | « tools/testing/test_case.py ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: tools/testing/test_configuration.py
===================================================================
--- tools/testing/test_configuration.py (revision 1300)
+++ tools/testing/test_configuration.py (working copy)
@@ -34,8 +34,8 @@
'static type error',
'dynamic type error'])
- def __init__(self, context, root):
- super(StandardTestConfiguration, self).__init__(context, root)
+ def __init__(self, context, root, flags = []):
+ super(StandardTestConfiguration, self).__init__(context, root, flags)
def _Cleanup(self, tests):
"""Remove any temporary files created by running the test."""
@@ -75,11 +75,12 @@
for options in vm_options_list:
tests.append(test_case.BrowserTestCase(
self.context, test_path, filename, False, mode, arch, component,
- options))
+ options + self.flags))
return tests
else:
return [test_case.BrowserTestCase(
- self.context, test_path, filename, False, mode, arch, component)]
+ self.context, test_path, filename, False, mode, arch, component,
+ options)]
else:
tests = []
if tags:
@@ -96,10 +97,11 @@
if vm_options_list:
for options in vm_options_list:
tests.append(test_case.StandardTestCase(self.context,
- test_path, filename, mode, arch, component, options))
+ test_path, filename, mode, arch, component,
+ options + self.flags))
else:
tests.append(test_case.StandardTestCase(self.context,
test_path, filename, mode, arch, component))
return tests
def ListTests(self, current_path, path, mode, arch, component):
« frog/tests/leg_only/leg_only.status ('K') | « tools/testing/test_case.py ('k') | no next file » | no next file with comments »
@@ -96,10 +97,11 @@
else:
tests.append(test_case.StandardTestCase(self.context,
- test_path, filename, mode, arch, component))
+ test_path, filename, mode, arch, component, self.flags))
return tests
def ListTests(self, current_path, path, mode, arch, component):

Powered by Google App Engine
This is Rietveld 408576698